﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Grids;
using System.Windows.Data;

namespace CloumnAlignment_SL
{
    public partial class MainPage : UserControl
    {
        
        int[] ColumnLengths = { 200, 100, 150, 100, 100, 100 };
        private int LayoutLevel = 0;
        public MainPage()
        {
            InitializeComponent();
            this.DataContext = new ViewModel();
        }

        private void myGrid_Loaded(object sender, RoutedEventArgs e)
        {
            // Assign initial column widths to force the bindings to update so the columns start at the correct values.
            for (int i = 0; i < myGrid.ColumnLayouts[0].Columns.DataColumns.Count; i++)
                myGrid.ColumnLayouts[0].Columns.DataColumns[i].Width = new ColumnWidth(ColumnLengths[i], false);
        }
       
        private void myGrid_ColumnLayoutAssigned(object sender, Infragistics.Controls.Grids.ColumnLayoutAssignedEventArgs e)
        {   
            // bind this column layout's columns to it's parent.
            if (e.Level > 0)
            {
                e.ColumnLayout.HeaderVisibility = Visibility.Collapsed;

                // the first column in children column layouts is the GridData.Children property.
                for (int i = 1; i < e.ColumnLayout.Columns.Count; i++)
                {
                    Column parentCol = null;
                    if (e.Level == 1)
                        parentCol = (Column)myGrid.ColumnLayouts[e.Level - 1].Columns[i - 1];
                    else
                        parentCol = (Column)myGrid.ColumnLayouts[e.Level - 1].Columns[i];

                    Column childCol = (Column)e.ColumnLayout.Columns[i];

                    // bind the widths together.
                    BindingOperations.SetBinding(childCol, Column.WidthProperty, new Binding
                    {
                        Path = new PropertyPath("Width"),
                        Source = parentCol,
                        Converter = (i == 1) ? new FirstColumnWidthConverter() { Indentation = myGrid.Indentation } : null,
                        ConverterParameter = e.Level,
                    });
                }
            }
        }
    }

    public class FirstColumnWidthConverter : IValueConverter
    {
        public double Indentation { get; set; }

        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value == null)
                return null;

            ColumnWidth newWidth = (ColumnWidth)value;
            int level = (int)parameter;

            return new ColumnWidth(newWidth.Value - Indentation, false);
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class ViewModel
    {
        public ObservableCollection<GridData> DataSource { get; set; }
        public ViewModel()
        {
            CreateData();
        }
        private void CreateData()
        {
            DataSource = new ObservableCollection<GridData>();
            Random r = new Random();
            for (int i = 0; i < 10; i++)
            {
                GridData gd = new GridData()
                {
                    ID = i,
                    Name = "Name" + i.ToString(),
                    RecDesc = "Description" + i.ToString(),
                    Length = r.NextDouble(),
                    Sales = 5 * r.NextDouble(),
                    Units = r.NextDouble(),
                    Children = new ObservableCollection<GridData>()
                };
                for (int j = 0; j < 5; j++)
                {
                    GridData gd2 = new GridData()
                    {
                        ID = i * 10 + j,
                        Name = "Name" + j.ToString(),
                        RecDesc = "Description" + j.ToString(),
                        Length = r.NextDouble(),
                        Sales = 5 * r.NextDouble(),
                        Units = r.NextDouble(),
                        Children = new ObservableCollection<GridData>()
                    };
                    for (int k = 0; k < 5; k++)
                    {
                        GridData gd3 = new GridData()
                        {
                            ID = i * 100 + j * 10 + k,
                            Name = "Name" + k.ToString(),
                            RecDesc = "Description" + k.ToString(),
                            Length = r.NextDouble(),
                            Sales = 5 * r.NextDouble(),
                            Units = r.NextDouble(),
                            Children = new ObservableCollection<GridData>()
                        };
                        for (int l = 0; l < 5; l++)
                        {
                            GridData gd4 = new GridData()
                            {
                                ID = i * 1000 + j * 100 + k * 10 + l,
                                Name = "Name" + l.ToString(),
                                RecDesc = "Description" + l.ToString(),
                                Length = r.NextDouble(),
                                Sales = 5 * r.NextDouble(),
                                Units = r.NextDouble(),
                                Children = new ObservableCollection<GridData>()
                            };
                            gd3.Children.Add(gd4);
                        }
                        gd2.Children.Add(gd3);
                    }
                    gd.Children.Add(gd2);
                }
                DataSource.Add(gd);
            }
        }

    }
}
